<?php

namespace Drupal\doi_search;

use Drupal\Core\Messenger\MessengerInterface;
use GuzzleHttp\ClientInterface;

/**
 * DoiSearchManager service.
 */
class DoiSearchManager {

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

   /**
   * The HTTP client.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * Constructs a DoiSearchManager object.
   *
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger.
   */
  public function __construct(MessengerInterface $messenger,ClientInterface $http_client) {
    $this->messenger = $messenger;
    $this->httpClient = $http_client;
  }

  
  /**
   * It takes a DOI as a parameter, makes a request to the CrossRef API, and returns the response as an
   * array
   * 
   * @param doi The DOI of the article you want to retrieve.
   * 
   * @return An array of data.
   */
  public function getData($doi) {
    try {
      $url = 'http://api.crossref.org/works/' . $doi;
      $request = $this->httpClient->request('GET', $url, ['http_errors' => false]);
      $data = json_decode($request->getBody());
      if (isset($data->message)){  
        return $data->message;
      }
      else {
        return [];
      }
    }
    catch (Exception $e) {
      $this->messenger->addError($this-t('Error retrieving Doi data'));
    }
  }

}
